/* This file was generated by upb_generator from the input file:
 *
 *     src/proto/grpc/gcp/handshaker.proto
 *
 * Do not edit -- your changes will be discarded when the file is
 * regenerated. */

#ifndef SRC_PROTO_GRPC_GCP_HANDSHAKER_PROTO_UPB_MINITABLE_H_
#define SRC_PROTO_GRPC_GCP_HANDSHAKER_PROTO_UPB_MINITABLE_H_

#include "upb/generated_code_support.h"

// Must be last.
#include "upb/port/def.inc"

#ifdef __cplusplus
extern "C" {
#endif

extern const upb_MiniTable grpc__gcp__Endpoint_msg_init;
extern const upb_MiniTable grpc__gcp__Identity_msg_init;
extern const upb_MiniTable grpc__gcp__Identity__AttributesEntry_msg_init;
extern const upb_MiniTable grpc__gcp__StartClientHandshakeReq_msg_init;
extern const upb_MiniTable grpc__gcp__ServerHandshakeParameters_msg_init;
extern const upb_MiniTable grpc__gcp__StartServerHandshakeReq_msg_init;
extern const upb_MiniTable grpc__gcp__StartServerHandshakeReq__HandshakeParametersEntry_msg_init;
extern const upb_MiniTable grpc__gcp__NextHandshakeMessageReq_msg_init;
extern const upb_MiniTable grpc__gcp__HandshakerReq_msg_init;
extern const upb_MiniTable grpc__gcp__HandshakerResult_msg_init;
extern const upb_MiniTable grpc__gcp__HandshakerStatus_msg_init;
extern const upb_MiniTable grpc__gcp__HandshakerResp_msg_init;

extern const upb_MiniTableFile src_proto_grpc_gcp_handshaker_proto_upb_file_layout;

#ifdef __cplusplus
}  /* extern "C" */
#endif

#include "upb/port/undef.inc"

#endif  /* SRC_PROTO_GRPC_GCP_HANDSHAKER_PROTO_UPB_MINITABLE_H_ */
